==> openshift-model-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/LocalResourceAccessReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class LocalResourceAccessReviewBuilder extends LocalResourceAccessReviewFluentImpl<LocalResourceAccessReviewBuilder> implements VisitableBuilder<LocalResourceAccessReview,LocalResourceAccessReviewBuilder> {

    LocalResourceAccessReviewFluent<?> fluent;
    Boolean validationEnabled;

    public LocalResourceAccessReviewBuilder() { 
        this(true);
    }


    public LocalResourceAccessReviewBuilder(Boolean validationEnabled) { 
        this(new LocalResourceAccessReview(), validationEnabled);
    }


    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent) { 
        this(fluent, true);
    }


    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new LocalResourceAccessReview(), validationEnabled);
    }


    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent,LocalResourceAccessReview instance) { 
        this(fluent, instance, true);
    }


    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent,LocalResourceAccessReview instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withContent(instance.getContent()); 
        fluent.withIsNonResourceURL(instance.getIsNonResourceURL()); 
        fluent.withKind(instance.getKind()); 
        fluent.withNamespace(instance.getNamespace()); 
        fluent.withPath(instance.getPath()); 
        fluent.withResource(instance.getResource()); 
        fluent.withResourceAPIGroup(instance.getResourceAPIGroup()); 
        fluent.withResourceAPIVersion(instance.getResourceAPIVersion()); 
        fluent.withResourceName(instance.getResourceName()); 
        fluent.withVerb(instance.getVerb()); 
        this.validationEnabled = validationEnabled; 
    }


    public LocalResourceAccessReviewBuilder(LocalResourceAccessReview instance) { 
        this(instance,true);
    }


    public LocalResourceAccessReviewBuilder(LocalResourceAccessReview instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withContent(instance.getContent()); 
        this.withIsNonResourceURL(instance.getIsNonResourceURL()); 
        this.withKind(instance.getKind()); 
        this.withNamespace(instance.getNamespace()); 
        this.withPath(instance.getPath()); 
        this.withResource(instance.getResource()); 
        this.withResourceAPIGroup(instance.getResourceAPIGroup()); 
        this.withResourceAPIVersion(instance.getResourceAPIVersion()); 
        this.withResourceName(instance.getResourceName()); 
        this.withVerb(instance.getVerb()); 
        this.validationEnabled = validationEnabled; 
    }


    public LocalResourceAccessReview build() {
        LocalResourceAccessReview buildable = new LocalResourceAccessReview(fluent.getApiVersion(),fluent.getContent(),fluent.isIsNonResourceURL(),fluent.getKind(),fluent.getNamespace(),fluent.getPath(),fluent.getResource(),fluent.getResourceAPIGroup(),fluent.getResourceAPIVersion(),fluent.getResourceName(),fluent.getVerb());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        LocalResourceAccessReviewBuilder that = (LocalResourceAccessReviewBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/LocalResourceAccessReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class LocalResourceAccessReviewBuilder extends LocalResourceAccessReviewFluentImpl<LocalResourceAccessReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<LocalResourceAccessReview,LocalResourceAccessReviewBuilder> {

    LocalResourceAccessReviewFluent<?> fluent;
    Boolean validationEnabled;

    public LocalResourceAccessReviewBuilder() {
        this(true);
    }

    public LocalResourceAccessReviewBuilder(Boolean validationEnabled) {
        this(new LocalResourceAccessReview(), validationEnabled);
    }

    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent) {
        this(fluent, true);
    }

    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new LocalResourceAccessReview(), validationEnabled);
    }

    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent,LocalResourceAccessReview instance) {
        this(fluent, instance, true);
    }

    public LocalResourceAccessReviewBuilder(LocalResourceAccessReviewFluent<?> fluent,LocalResourceAccessReview instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withContent(instance.getContent()); 
        fluent.withIsNonResourceURL(instance.getIsNonResourceURL()); 
        fluent.withKind(instance.getKind()); 
        fluent.withNamespace(instance.getNamespace()); 
        fluent.withPath(instance.getPath()); 
        fluent.withResource(instance.getResource()); 
        fluent.withResourceAPIGroup(instance.getResourceAPIGroup()); 
        fluent.withResourceAPIVersion(instance.getResourceAPIVersion()); 
        fluent.withResourceName(instance.getResourceName()); 
        fluent.withVerb(instance.getVerb()); 
        this.validationEnabled = validationEnabled; 
    }

    public LocalResourceAccessReviewBuilder(LocalResourceAccessReview instance) {
        this(instance,true);
    }

    public LocalResourceAccessReviewBuilder(LocalResourceAccessReview instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withContent(instance.getContent()); 
        this.withIsNonResourceURL(instance.getIsNonResourceURL()); 
        this.withKind(instance.getKind()); 
        this.withNamespace(instance.getNamespace()); 
        this.withPath(instance.getPath()); 
        this.withResource(instance.getResource()); 
        this.withResourceAPIGroup(instance.getResourceAPIGroup()); 
        this.withResourceAPIVersion(instance.getResourceAPIVersion()); 
        this.withResourceName(instance.getResourceName()); 
        this.withVerb(instance.getVerb()); 
        this.validationEnabled = validationEnabled; 
    }

    public LocalResourceAccessReview build() {
        LocalResourceAccessReview buildable = new LocalResourceAccessReview(fluent.getApiVersion(),fluent.getContent(),fluent.getIsNonResourceURL(),fluent.getKind(),fluent.getNamespace(),fluent.getPath(),fluent.getResource(),fluent.getResourceAPIGroup(),fluent.getResourceAPIVersion(),fluent.getResourceName(),fluent.getVerb());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        LocalResourceAccessReviewBuilder that = (LocalResourceAccessReviewBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
